# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

import cohesivenet
from cohesivenet.api.vns3.overlay_network_api import OverlayNetworkApi  # noqa: E501
from cohesivenet.rest import ApiException


@pytest.mark.licensed
class TestOverlayNetworkApi(object):
    """OverlayNetworkApi unit test stubs"""

    def test_delete_clientpack_tag(self):
        """Test case for delete_clientpack_tag

        """
        pass

    def test_get_clientpack(self):
        """Test case for get_clientpack

        """
        pass

    def test_get_clientpacks(self):
        """Test case for get_clientpacks

        """
        pass

    def test_get_clients_status(self):
        """Test case for get_clients_status

        """
        pass

    def test_get_connected_subnets(self):
        """Test case for get_connected_subnets

        """
        pass

    def test_get_download_clientpack(self):
        """Test case for get_download_clientpack

        """
        pass

    def test_post_calc_next_clientpack(self):
        """Test case for post_calc_next_clientpack

        """
        pass

    def test_post_clientpack_tag(self):
        """Test case for post_clientpack_tag

        """
        pass

    def test_post_reset_all_clients(self):
        """Test case for post_reset_all_clients

        """
        pass

    def test_post_reset_client(self):
        """Test case for post_reset_client

        """
        pass

    def test_put_add_clientpacks(self):
        """Test case for put_add_clientpacks

        """
        pass

    def test_put_clientpack(self):
        """Test case for put_clientpack

        """
        pass

    def test_put_disconnect_clientpack(self):
        """Test case for put_disconnect_clientpack

        """
        pass

    def test_put_update_clientpacks(self):
        """Test case for put_update_clientpacks

        """
        pass



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cohesivenet.exceptions import ApiTypeError, ApiValueError


class MonitoringAlertingApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            from cohesivenet.vns3_client import VNS3Client

            api_client = VNS3Client()
        self.api_client = api_client

    def get_webhooks(self, **kwargs):  # noqa: E501
        """get_webhooks  # noqa: E501

        Retrieve all Alert integrations (webhooks)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_webhooks(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: WebhooksListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_webhooks_with_http_info(**kwargs)  # noqa: E501

    def get_webhooks_with_http_info(self, **kwargs):  # noqa: E501
        """get_webhooks  # noqa: E501

        Retrieve all Alert integrations (webhooks)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_webhooks_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(WebhooksListResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_webhooks" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/webhooks",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="WebhooksListResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_webhook(self, webhook_id, **kwargs):  # noqa: E501
        """get_webhook  # noqa: E501

        Retrieve details for single webhook integration  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_webhook(webhook_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int webhook_id: ID for webhook integration (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: WebhookDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_webhook_with_http_info(webhook_id, **kwargs)  # noqa: E501

    def get_webhook_with_http_info(self, webhook_id, **kwargs):  # noqa: E501
        """get_webhook  # noqa: E501

        Retrieve details for single webhook integration  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_webhook_with_http_info(webhook_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int webhook_id: ID for webhook integration (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(WebhookDetailResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["webhook_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_webhook" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'webhook_id' is set
        if self.api_client.client_side_validation and (
            "webhook_id" not in local_var_params
            or local_var_params["webhook_id"] is None
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `webhook_id` when calling `get_webhook`"
            )  # noqa: E501

        if (
            self.api_client.client_side_validation
            and "webhook_id" in local_var_params
            and local_var_params["webhook_id"] < 0
        ):  # noqa: E501
            raise ApiValueError(
                "Invalid value for parameter `webhook_id` when calling `get_webhook`, must be a value greater than or equal to `0`"
            )  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "webhook_id" in local_var_params:
            path_params["webhook_id"] = local_var_params["webhook_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/webhook/{webhook_id}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="WebhookDetailResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_create_webhook(self, create_webhook_request, **kwargs):  # noqa: E501
        """post_create_webhook  # noqa: E501

        Define new Webhook integration  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_create_webhook(create_webhook_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreatewebhookRequest create_webhook_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: WebhookDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_create_webhook_with_http_info(
            create_webhook_request, **kwargs
        )  # noqa: E501

    def post_create_webhook_with_http_info(
        self, create_webhook_request, **kwargs
    ):  # noqa: E501
        """post_create_webhook  # noqa: E501

        Define new Webhook integration  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_create_webhook_with_http_info(create_webhook_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreatewebhookRequest create_webhook_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(WebhookDetailResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["create_webhook_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_create_webhook" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'create_webhook_request' is set
        if self.api_client.client_side_validation and (
            "create_webhook_request" not in local_var_params
            or local_var_params["create_webhook_request"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `create_webhook_request` when calling `post_create_webhook`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "create_webhook_request" in local_var_params:
            body_params = local_var_params["create_webhook_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/webhook",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="WebhookDetailResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def put_update_webhook(
        self, webhook_id, update_webhook_request, **kwargs
    ):  # noqa: E501
        """put_update_webhook  # noqa: E501

        Edit defined webhook integration  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_update_webhook(webhook_id, update_webhook_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int webhook_id: ID for webhook integration (required)
        :param UpdateWebhookRequest update_webhook_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: WebhookDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.put_update_webhook_with_http_info(
            webhook_id, update_webhook_request, **kwargs
        )  # noqa: E501

    def put_update_webhook_with_http_info(
        self, webhook_id, update_webhook_request, **kwargs
    ):  # noqa: E501
        """put_update_webhook  # noqa: E501

        Edit defined webhook integration  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_update_webhook_with_http_info(webhook_id, update_webhook_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int webhook_id: ID for webhook integration (required)
        :param UpdateWebhookRequest update_webhook_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(WebhookDetailResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["webhook_id", "update_webhook_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_update_webhook" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'webhook_id' is set
        if self.api_client.client_side_validation and (
            "webhook_id" not in local_var_params
            or local_var_params["webhook_id"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `webhook_id` when calling `put_update_webhook`"
            )  # noqa: E501
        # verify the required parameter 'update_webhook_request' is set
        if self.api_client.client_side_validation and (
            "update_webhook_request" not in local_var_params
            or local_var_params["update_webhook_request"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `update_webhook_request` when calling `put_update_webhook`"
            )  # noqa: E501

        if (
            self.api_client.client_side_validation
            and "webhook_id" in local_var_params
            and local_var_params["webhook_id"] < 0
        ):  # noqa: E501
            raise ApiValueError(
                "Invalid value for parameter `webhook_id` when calling `put_update_webhook`, must be a value greater than or equal to `0`"
            )  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "webhook_id" in local_var_params:
            path_params["webhook_id"] = local_var_params["webhook_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "update_webhook_request" in local_var_params:
            body_params = local_var_params["update_webhook_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/webhook/{webhook_id}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="WebhookDetailResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def delete_webhook(self, webhook_id, **kwargs):  # noqa: E501
        """delete_webhook  # noqa: E501

        Delete defined webhook integration  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_webhook(webhook_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int webhook_id: ID for webhook integration (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: WebhookDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.delete_webhook_with_http_info(webhook_id, **kwargs)  # noqa: E501

    def delete_webhook_with_http_info(self, webhook_id, **kwargs):  # noqa: E501
        """delete_webhook  # noqa: E501

        Delete defined webhook integration  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_webhook_with_http_info(webhook_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int webhook_id: ID for webhook integration (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["webhook_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_webhook" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'webhook_id' is set
        if self.api_client.client_side_validation and (
            "webhook_id" not in local_var_params
            or local_var_params["webhook_id"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `webhook_id` when calling `delete_webhook`"
            )  # noqa: E501

        if (
            self.api_client.client_side_validation
            and "webhook_id" in local_var_params
            and local_var_params["webhook_id"] < 0
        ):  # noqa: E501
            raise ApiValueError(
                "Invalid value for parameter `webhook_id` when calling `delete_webhook`, must be a value greater than or equal to `0`"
            )  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "webhook_id" in local_var_params:
            path_params["webhook_id"] = local_var_params["webhook_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/webhook/{webhook_id}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="WebhookDetailResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def delete_alert(self, **kwargs):  # noqa: E501
        """delete_alert  # noqa: E501

        Delete defined alert  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_alert(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.delete_alert_with_http_info(**kwargs)  # noqa: E501

    def delete_alert_with_http_info(self, **kwargs):  # noqa: E501
        """delete_alert  # noqa: E501

        Delete defined alert  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_alert_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_alert" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/alert/{alert_id}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_alert(self, alert_id, **kwargs):  # noqa: E501
        """get_alert  # noqa: E501

        Retrieve details for single alert  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_alert(alert_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int alert_id: ID for Alert definition (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AlertDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_alert_with_http_info(alert_id, **kwargs)  # noqa: E501

    def get_alert_with_http_info(self, alert_id, **kwargs):  # noqa: E501
        """get_alert  # noqa: E501

        Retrieve details for single alert  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_alert_with_http_info(alert_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int alert_id: ID for Alert definition (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AlertDetailResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["alert_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_alert" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'alert_id' is set
        if self.api_client.client_side_validation and (
            "alert_id" not in local_var_params
            or local_var_params["alert_id"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `alert_id` when calling `get_alert`"
            )  # noqa: E501

        if (
            self.api_client.client_side_validation
            and "alert_id" in local_var_params
            and local_var_params["alert_id"] < 0
        ):  # noqa: E501
            raise ApiValueError(
                "Invalid value for parameter `alert_id` when calling `get_alert`, must be a value greater than or equal to `0`"
            )  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "alert_id" in local_var_params:
            path_params["alert_id"] = local_var_params["alert_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/alert/{alert_id}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="AlertDetailResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_alerts(self, **kwargs):  # noqa: E501
        """get_alerts  # noqa: E501

        Retrieve all alerts  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_alerts(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AlertsListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_alerts_with_http_info(**kwargs)  # noqa: E501

    def get_alerts_with_http_info(self, **kwargs):  # noqa: E501
        """get_alerts  # noqa: E501

        Retrieve all alerts  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_alerts_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AlertsListResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_alerts" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/alerts",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="AlertsListResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_define_new_alert(self, create_alert_request, **kwargs):  # noqa: E501
        """post_define_new_alert  # noqa: E501

        Define new alert  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_define_new_alert(create_alert_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateAlertRequest create_alert_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AlertDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_define_new_alert_with_http_info(
            create_alert_request, **kwargs
        )  # noqa: E501

    def post_define_new_alert_with_http_info(
        self, create_alert_request, **kwargs
    ):  # noqa: E501
        """post_define_new_alert  # noqa: E501

        Define new alert  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_define_new_alert_with_http_info(create_alert_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateAlertRequest create_alert_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AlertDetailResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["create_alert_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_define_new_alert" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'create_alert_request' is set
        if (
            "create_alert_request" not in local_var_params
            or local_var_params["create_alert_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `create_alert_request` when calling `post_define_new_alert`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "create_alert_request" in local_var_params:
            body_params = local_var_params["create_alert_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/alert",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="AlertDetailResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_test_alert(self, alert_id, **kwargs):  # noqa: E501
        """post_test_alert  # noqa: E501

        Send test alert for this defined alert  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_test_alert(alert_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int alert_id: ID for Alert definition (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SimpleBooleanResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_test_alert_with_http_info(alert_id, **kwargs)  # noqa: E501

    def post_test_alert_with_http_info(self, alert_id, **kwargs):  # noqa: E501
        """post_test_alert  # noqa: E501

        Send test alert for this defined alert  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_test_alert_with_http_info(alert_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int alert_id: ID for Alert definition (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SimpleBooleanResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["alert_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_test_alert" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'alert_id' is set
        if "alert_id" not in local_var_params or local_var_params["alert_id"] is None:
            raise ApiValueError(
                "Missing the required parameter `alert_id` when calling `post_test_alert`"
            )  # noqa: E501

        if (
            "alert_id" in local_var_params and local_var_params["alert_id"] < 0
        ):  # noqa: E501
            raise ApiValueError(
                "Invalid value for parameter `alert_id` when calling `post_test_alert`, must be a value greater than or equal to `0`"
            )  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "alert_id" in local_var_params:
            path_params["alert_id"] = local_var_params["alert_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/alert/{alert_id}/test",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="SimpleBooleanResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_toggle_enabled_alert(self, alert_id, **kwargs):  # noqa: E501
        """post_toggle_enabled_alert  # noqa: E501

        Toggle enabled property on alert  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_toggle_enabled_alert(alert_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int alert_id: ID for Alert definition (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_toggle_enabled_alert_with_http_info(
            alert_id, **kwargs
        )  # noqa: E501

    def post_toggle_enabled_alert_with_http_info(
        self, alert_id, **kwargs
    ):  # noqa: E501
        """post_toggle_enabled_alert  # noqa: E501

        Toggle enabled property on alert  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_toggle_enabled_alert_with_http_info(alert_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int alert_id: ID for Alert definition (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["alert_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_toggle_enabled_alert" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'alert_id' is set
        if "alert_id" not in local_var_params or local_var_params["alert_id"] is None:
            raise ApiValueError(
                "Missing the required parameter `alert_id` when calling `post_toggle_enabled_alert`"
            )  # noqa: E501

        if (
            "alert_id" in local_var_params and local_var_params["alert_id"] < 0
        ):  # noqa: E501
            raise ApiValueError(
                "Invalid value for parameter `alert_id` when calling `post_toggle_enabled_alert`, must be a value greater than or equal to `0`"
            )  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "alert_id" in local_var_params:
            path_params["alert_id"] = local_var_params["alert_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/alert/{alert_id}/toggle_enabled",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def put_update_alert(self, alert_id, update_alert_request, **kwargs):  # noqa: E501
        """put_update_alert  # noqa: E501

        Edit defined alert  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_update_alert(alert_id, update_alert_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int alert_id: ID for Alert definition (required)
        :param UpdateAlertRequest update_alert_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.put_update_alert_with_http_info(
            alert_id, update_alert_request, **kwargs
        )  # noqa: E501

    def put_update_alert_with_http_info(
        self, alert_id, update_alert_request, **kwargs
    ):  # noqa: E501
        """put_update_alert  # noqa: E501

        Edit defined alert  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_update_alert_with_http_info(alert_id, update_alert_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int alert_id: ID for Alert definition (required)
        :param UpdateAlertRequest update_alert_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["alert_id", "update_alert_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_update_alert" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'alert_id' is set
        if "alert_id" not in local_var_params or local_var_params["alert_id"] is None:
            raise ApiValueError(
                "Missing the required parameter `alert_id` when calling `put_update_alert`"
            )  # noqa: E501
        # verify the required parameter 'update_alert_request' is set
        if (
            "update_alert_request" not in local_var_params
            or local_var_params["update_alert_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `update_alert_request` when calling `put_update_alert`"
            )  # noqa: E501

        if (
            "alert_id" in local_var_params and local_var_params["alert_id"] < 0
        ):  # noqa: E501
            raise ApiValueError(
                "Invalid value for parameter `alert_id` when calling `put_update_alert`, must be a value greater than or equal to `0`"
            )  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "alert_id" in local_var_params:
            path_params["alert_id"] = local_var_params["alert_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "update_alert_request" in local_var_params:
            body_params = local_var_params["update_alert_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/alert/{alert_id}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

from tests.rest_mock import RestClientMock

from cohesivenet import VNS3Client, models, Configuration
from cohesivenet.rest import ApiException


class TestSystemAdministrationApi(object):
    """SystemAdministrationApi unit test stubs. Unlicensed allowed"""

    def test_delete_access_url(self):
        """Test case for delete_access_url

        """
        pass

    def test_delete_access_url_by_id(self):
        """Test case for delete_access_url_by_id

        """
        pass

    def test_delete_api_access_token(self):
        """Test case for delete_api_access_token

        """
        pass

    def test_get_access_urls(self):
        """Test case for get_access_urls

        """
        pass

    def test_get_access_url(self):
        """Test case for get_access_url

        """
        pass

    def test_get_api_access_token(self):
        """Test case for get_api_access_token

        """
        pass

    def test_get_api_access_tokens(self):
        """Test case for get_api_access_tokens

        """
        pass

    def test_get_cloud_data_aws(self, rest_mock: RestClientMock):
        """Test case for get_cloud_data

        """
        rest_mock.stub_request(
            "get",
            "/api/cloud_data",
            {
                "response": {
                    "cloud_data": {
                        "accountId": "947761958079",
                        "architecture": "x86_64",
                        "availabilityZone": "us-east-1a",
                        "billingProducts": None,
                        "devpayProductCodes": None,
                        "imageId": "ami-034b377bde620d2a8",
                        "instanceId": "i-0b96e779c3143cf66",
                        "instanceType": "t3.small",
                        "kernelId": None,
                        "marketplaceProductCodes": None,
                        "pendingTime": "2019-11-08T16:18:38Z",
                        "privateIp": "10.0.1.37",
                        "ramdiskId": None,
                        "region": "us-east-1",
                        "version": "2017-09-30",
                    },
                    "cloud_type": "ec2",
                }
            },
        )

        api_client = VNS3Client(
            configuration=Configuration(
                host="0.0.0.0:8000",
                username="api",
                password="password",
                verify_ssl=False,
            )
        )

        resp = api_client.sys_admin.get_cloud_data()
        assert type(resp) is models.CloudInfoDetail
        assert resp.response.cloud_type == "ec2"
        assert resp.response.cloud_data["accountId"] == "947761958079"

    @pytest.mark.licensed
    def test_get_status(self):
        """Test case for get_status

        """
        pass

    @pytest.mark.licensed
    def test_get_system_status(self):
        """Test case for get_system_status

        """
        pass

    @pytest.mark.licensed
    def test_get_task_status(self):
        """Test case for get_task_status

        """
        pass

    def test_post_create_access_url(self):
        """Test case for post_create_access_url

        """
        pass

    def test_post_create_api_access_token(self):
        """Test case for post_create_api_access_token

        """
        pass

    def test_post_generate_keypair(self):
        """Test case for post_generate_keypair

        """
        pass

    def test_put_expire_access_url(self):
        """Test case for put_expire_access_url

        """
        pass

    def test_put_expire_api_access_token(self):
        """Test case for put_expire_api_access_token

        """
        pass

    def test_put_remote_support(self, rest_mock: RestClientMock):
        """Test case for put_remote_support

        """
        method, uri = "put", "/api/remote_support"
        rest_mock.stub_request(
            method, uri, {"response": {"enabled": False, "revoke_credential": True}}
        )

        api_client = VNS3Client(
            configuration=Configuration(
                host="0.0.0.0:8000",
                username="api",
                password="password",
                verify_ssl=False,
            )
        )

        request = {"enabled": False, "revoke": True}
        resp = api_client.sys_admin.put_remote_support(request)
        assert type(resp) is models.RemoteSupportStatusResponse
        assert not resp.response.enabled and resp.response.revoke_credential
        rest_mock.assert_requested(method, uri, body=request)

    @pytest.mark.licensed
    def test_put_server_action(self):
        """Test case for put_server_action

        """
        pass



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cohesivenet.exceptions import ApiTypeError, ApiValueError


class PeeringApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            from cohesivenet.vns3_client import VNS3Client

            api_client = VNS3Client()
        self.api_client = api_client

    def delete_peer(self, peer_id, **kwargs):  # noqa: E501
        """delete_peer  # noqa: E501

        Breaks a peering relationship from a manager to another manager.  The peering call is unidirectional. Reciprocal calls must be made to  fully break the peer relationship.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_peer(peer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int peer_id: Peer ID for controller peer (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.delete_peer_with_http_info(peer_id, **kwargs)  # noqa: E501

    def delete_peer_with_http_info(self, peer_id, **kwargs):  # noqa: E501
        """delete_peer  # noqa: E501

        Breaks a peering relationship from a manager to another manager.  The peering call is unidirectional. Reciprocal calls must be made to  fully break the peer relationship.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_peer_with_http_info(peer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int peer_id: Peer ID for controller peer (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["peer_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_peer" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'peer_id' is set
        if "peer_id" not in local_var_params or local_var_params["peer_id"] is None:
            raise ApiValueError(
                "Missing the required parameter `peer_id` when calling `delete_peer`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "peer_id" in local_var_params:
            path_params["peer_id"] = local_var_params["peer_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/peering/peers/{peer_id}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_peering_status(self, **kwargs):  # noqa: E501
        """get_peering_status  # noqa: E501

        Provides the status of whether a Controller is peered to other Controllers  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_peering_status(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PeersDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_peering_status_with_http_info(**kwargs)  # noqa: E501

    def get_peering_status_with_http_info(self, **kwargs):  # noqa: E501
        """get_peering_status  # noqa: E501

        Provides the status of whether a Controller is peered to other Controllers  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_peering_status_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PeersDetailResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_peering_status" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/peering",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="PeersDetailResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_peer(self, create_peer_request, **kwargs):  # noqa: E501
        """post_peer  # noqa: E501

        Creates a peering relationship from a manager to another manager.  The peering call is unidirectional. Reciprocal calls must be made to peer two controllers  together and complete the peering process.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_peer(create_peer_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreatePeerRequest create_peer_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_peer_with_http_info(
            create_peer_request, **kwargs
        )  # noqa: E501

    def post_peer_with_http_info(self, create_peer_request, **kwargs):  # noqa: E501
        """post_peer  # noqa: E501

        Creates a peering relationship from a manager to another manager.  The peering call is unidirectional. Reciprocal calls must be made to peer two controllers  together and complete the peering process.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_peer_with_http_info(create_peer_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreatePeerRequest create_peer_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["create_peer_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_peer" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'create_peer_request' is set
        if (
            "create_peer_request" not in local_var_params
            or local_var_params["create_peer_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `create_peer_request` when calling `post_peer`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "create_peer_request" in local_var_params:
            body_params = local_var_params["create_peer_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/peering/peers",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def put_peer(self, peer_id, update_peer_request, **kwargs):  # noqa: E501
        """put_peer  # noqa: E501

        Edits a peering relationship from a manager to another manager.  The peering call is unidirectional. Reciprocal calls must be made to peer two controllers  together and complete the peering process.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_peer(update_peer_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int peer_id: ID for Peer (required)
        :param UpdatePeerRequest update_peer_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.put_peer_with_http_info(peer_id, update_peer_request, **kwargs)  # noqa: E501

    def put_peer_with_http_info(self, peer_id, update_peer_request, **kwargs):  # noqa: E501
        """put_peer  # noqa: E501

        Edits a peering relationship from a manager to another manager.  The peering call is unidirectional. Reciprocal calls must be made to peer two controllers  together and complete the peering process.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_peer_with_http_info(update_peer_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int peer_id: ID for Peer (required)
        :param UpdatePeerRequest update_peer_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["peer_id", "update_peer_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        # verify the required parameter 'peer_id' is set
        if self.api_client.client_side_validation and (
            "peer_id" not in local_var_params
            or local_var_params["peer_id"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `peer_id` when calling `put_peer`"
            )  # noqa: E501

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_peer" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'update_peer_request' is set
        if (
            "update_peer_request" not in local_var_params
            or local_var_params["update_peer_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `update_peer_request` when calling `put_peer`"
            )  # noqa: E501

        if (
            self.api_client.client_side_validation
            and "peer_id" in local_var_params
            and local_var_params["peer_id"] < 0
        ):  # noqa: E501
            raise ApiValueError(
                "Invalid value for parameter `peer_id` when calling `put_peer`, must be a value greater than or equal to `0`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "peer_id" in local_var_params:
            path_params["peer_id"] = local_var_params["peer_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "update_peer_request" in local_var_params:
            body_params = local_var_params["update_peer_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/peering/peers/{peer_id}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def put_reconfigure_peers(self, configure_peer_request, **kwargs):  # noqa: E501
        """put_reconfigure_peers  # noqa: E501

        Reconfigure peered controllers  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_reconfigure_peers(configure_peer_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ConfigurePeerRequest configure_peer_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.put_reconfigure_peers_with_http_info(
            configure_peer_request, **kwargs
        )  # noqa: E501

    def put_reconfigure_peers_with_http_info(
        self, configure_peer_request, **kwargs
    ):  # noqa: E501
        """put_reconfigure_peers  # noqa: E501

        Reconfigure peered controllers  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_reconfigure_peers_with_http_info(configure_peer_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ConfigurePeerRequest configure_peer_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["configure_peer_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_reconfigure_peers" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'configure_peer_request' is set
        if (
            "configure_peer_request" not in local_var_params
            or local_var_params["configure_peer_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `configure_peer_request` when calling `put_reconfigure_peers`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "configure_peer_request" in local_var_params:
            body_params = local_var_params["configure_peer_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/peering",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def put_self_peering_id(self, peer_self_request, **kwargs):  # noqa: E501
        """put_self_peering_id  # noqa: E501

        Sets the Controller ID of a controller so that it can be peered within a topology  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_self_peering_id(peer_self_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param PeerSelfRequest peer_self_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PeersDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.put_self_peering_id_with_http_info(
            peer_self_request, **kwargs
        )  # noqa: E501

    def put_self_peering_id_with_http_info(
        self, peer_self_request, **kwargs
    ):  # noqa: E501
        """put_self_peering_id  # noqa: E501

        Sets the Controller ID of a controller so that it can be peered within a topology  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_self_peering_id_with_http_info(peer_self_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param PeerSelfRequest peer_self_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PeersDetailResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["peer_self_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_self_peering_id" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'peer_self_request' is set
        if (
            "peer_self_request" not in local_var_params
            or local_var_params["peer_self_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `peer_self_request` when calling `put_self_peering_id`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "peer_self_request" in local_var_params:
            body_params = local_var_params["peer_self_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/peering/self",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="PeersDetailResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class RunningContainersDetailNetworkSettings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "ip_address": "str",
        "ip_prefix_len": "int",
        "gateway": "str",
        "bridge": "str",
        "port_mapping": "dict(str, object)",
        "ports": "dict(str, object)",
    }

    attribute_map = {
        "ip_address": "IPAddress",
        "ip_prefix_len": "IPPrefixLen",
        "gateway": "Gateway",
        "bridge": "Bridge",
        "port_mapping": "PortMapping",
        "ports": "Ports",
    }

    def __init__(
        self,
        ip_address=None,
        ip_prefix_len=None,
        gateway=None,
        bridge=None,
        port_mapping=None,
        ports=None,
    ):  # noqa: E501
        """RunningContainersDetailNetworkSettings - a model defined in OpenAPI"""  # noqa: E501

        self._ip_address = None
        self._ip_prefix_len = None
        self._gateway = None
        self._bridge = None
        self._port_mapping = None
        self._ports = None
        self.discriminator = None

        if ip_address is not None:
            self.ip_address = ip_address
        if ip_prefix_len is not None:
            self.ip_prefix_len = ip_prefix_len
        if gateway is not None:
            self.gateway = gateway
        if bridge is not None:
            self.bridge = bridge
        self.port_mapping = port_mapping
        self.ports = ports

    @property
    def ip_address(self):
        """Gets the ip_address of this RunningContainersDetailNetworkSettings.  # noqa: E501


        :return: The ip_address of this RunningContainersDetailNetworkSettings.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this RunningContainersDetailNetworkSettings.


        :param ip_address: The ip_address of this RunningContainersDetailNetworkSettings.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    @property
    def ip_prefix_len(self):
        """Gets the ip_prefix_len of this RunningContainersDetailNetworkSettings.  # noqa: E501


        :return: The ip_prefix_len of this RunningContainersDetailNetworkSettings.  # noqa: E501
        :rtype: int
        """
        return self._ip_prefix_len

    @ip_prefix_len.setter
    def ip_prefix_len(self, ip_prefix_len):
        """Sets the ip_prefix_len of this RunningContainersDetailNetworkSettings.


        :param ip_prefix_len: The ip_prefix_len of this RunningContainersDetailNetworkSettings.  # noqa: E501
        :type: int
        """

        self._ip_prefix_len = ip_prefix_len

    @property
    def gateway(self):
        """Gets the gateway of this RunningContainersDetailNetworkSettings.  # noqa: E501


        :return: The gateway of this RunningContainersDetailNetworkSettings.  # noqa: E501
        :rtype: str
        """
        return self._gateway

    @gateway.setter
    def gateway(self, gateway):
        """Sets the gateway of this RunningContainersDetailNetworkSettings.


        :param gateway: The gateway of this RunningContainersDetailNetworkSettings.  # noqa: E501
        :type: str
        """

        self._gateway = gateway

    @property
    def bridge(self):
        """Gets the bridge of this RunningContainersDetailNetworkSettings.  # noqa: E501


        :return: The bridge of this RunningContainersDetailNetworkSettings.  # noqa: E501
        :rtype: str
        """
        return self._bridge

    @bridge.setter
    def bridge(self, bridge):
        """Sets the bridge of this RunningContainersDetailNetworkSettings.


        :param bridge: The bridge of this RunningContainersDetailNetworkSettings.  # noqa: E501
        :type: str
        """

        self._bridge = bridge

    @property
    def port_mapping(self):
        """Gets the port_mapping of this RunningContainersDetailNetworkSettings.  # noqa: E501


        :return: The port_mapping of this RunningContainersDetailNetworkSettings.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._port_mapping

    @port_mapping.setter
    def port_mapping(self, port_mapping):
        """Sets the port_mapping of this RunningContainersDetailNetworkSettings.


        :param port_mapping: The port_mapping of this RunningContainersDetailNetworkSettings.  # noqa: E501
        :type: dict(str, object)
        """

        self._port_mapping = port_mapping

    @property
    def ports(self):
        """Gets the ports of this RunningContainersDetailNetworkSettings.  # noqa: E501


        :return: The ports of this RunningContainersDetailNetworkSettings.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._ports

    @ports.setter
    def ports(self, ports):
        """Sets the ports of this RunningContainersDetailNetworkSettings.


        :param ports: The ports of this RunningContainersDetailNetworkSettings.  # noqa: E501
        :type: dict(str, object)
        """

        self._ports = ports

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RunningContainersDetailNetworkSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class IpsecLocalEndpoint(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "nat_traversal": "bool",
        "ipaddress": "str",
        "overlay_subnet": "str",
        "private_ipaddress": "str",
        "ipsec_local_ipaddress": "str",
        "asn": "int",
    }

    attribute_map = {
        "nat_traversal": "nat_traversal",
        "ipaddress": "ipaddress",
        "overlay_subnet": "overlay_subnet",
        "private_ipaddress": "private_ipaddress",
        "ipsec_local_ipaddress": "ipsec_local_ipaddress",
        "asn": "asn",
    }

    def __init__(
        self,
        nat_traversal=None,
        ipaddress=None,
        overlay_subnet=None,
        private_ipaddress=None,
        ipsec_local_ipaddress=None,
        asn=None,
    ):  # noqa: E501
        """IpsecLocalEndpoint - a model defined in OpenAPI"""  # noqa: E501

        self._nat_traversal = None
        self._ipaddress = None
        self._overlay_subnet = None
        self._private_ipaddress = None
        self._ipsec_local_ipaddress = None
        self._asn = None
        self.discriminator = None

        if nat_traversal is not None:
            self.nat_traversal = nat_traversal
        if ipaddress is not None:
            self.ipaddress = ipaddress
        if overlay_subnet is not None:
            self.overlay_subnet = overlay_subnet
        if private_ipaddress is not None:
            self.private_ipaddress = private_ipaddress
        if ipsec_local_ipaddress is not None:
            self.ipsec_local_ipaddress = ipsec_local_ipaddress
        if asn is not None:
            self.asn = asn

    @property
    def nat_traversal(self):
        """Gets the nat_traversal of this IpsecLocalEndpoint.  # noqa: E501


        :return: The nat_traversal of this IpsecLocalEndpoint.  # noqa: E501
        :rtype: bool
        """
        return self._nat_traversal

    @nat_traversal.setter
    def nat_traversal(self, nat_traversal):
        """Sets the nat_traversal of this IpsecLocalEndpoint.


        :param nat_traversal: The nat_traversal of this IpsecLocalEndpoint.  # noqa: E501
        :type: bool
        """

        self._nat_traversal = nat_traversal

    @property
    def ipaddress(self):
        """Gets the ipaddress of this IpsecLocalEndpoint.  # noqa: E501


        :return: The ipaddress of this IpsecLocalEndpoint.  # noqa: E501
        :rtype: str
        """
        return self._ipaddress

    @ipaddress.setter
    def ipaddress(self, ipaddress):
        """Sets the ipaddress of this IpsecLocalEndpoint.


        :param ipaddress: The ipaddress of this IpsecLocalEndpoint.  # noqa: E501
        :type: str
        """

        self._ipaddress = ipaddress

    @property
    def overlay_subnet(self):
        """Gets the overlay_subnet of this IpsecLocalEndpoint.  # noqa: E501


        :return: The overlay_subnet of this IpsecLocalEndpoint.  # noqa: E501
        :rtype: str
        """
        return self._overlay_subnet

    @overlay_subnet.setter
    def overlay_subnet(self, overlay_subnet):
        """Sets the overlay_subnet of this IpsecLocalEndpoint.


        :param overlay_subnet: The overlay_subnet of this IpsecLocalEndpoint.  # noqa: E501
        :type: str
        """

        self._overlay_subnet = overlay_subnet

    @property
    def private_ipaddress(self):
        """Gets the private_ipaddress of this IpsecLocalEndpoint.  # noqa: E501


        :return: The private_ipaddress of this IpsecLocalEndpoint.  # noqa: E501
        :rtype: str
        """
        return self._private_ipaddress

    @private_ipaddress.setter
    def private_ipaddress(self, private_ipaddress):
        """Sets the private_ipaddress of this IpsecLocalEndpoint.


        :param private_ipaddress: The private_ipaddress of this IpsecLocalEndpoint.  # noqa: E501
        :type: str
        """

        self._private_ipaddress = private_ipaddress

    @property
    def ipsec_local_ipaddress(self):
        """Gets the ipsec_local_ipaddress of this IpsecLocalEndpoint.  # noqa: E501


        :return: The ipsec_local_ipaddress of this IpsecLocalEndpoint.  # noqa: E501
        :rtype: str
        """
        return self._ipsec_local_ipaddress

    @ipsec_local_ipaddress.setter
    def ipsec_local_ipaddress(self, ipsec_local_ipaddress):
        """Sets the ipsec_local_ipaddress of this IpsecLocalEndpoint.


        :param ipsec_local_ipaddress: The ipsec_local_ipaddress of this IpsecLocalEndpoint.  # noqa: E501
        :type: str
        """

        self._ipsec_local_ipaddress = ipsec_local_ipaddress

    @property
    def asn(self):
        """Gets the asn of this IpsecLocalEndpoint.  # noqa: E501


        :return: The asn of this IpsecLocalEndpoint.  # noqa: E501
        :rtype: int
        """
        return self._asn

    @asn.setter
    def asn(self, asn):
        """Sets the asn of this IpsecLocalEndpoint.


        :param asn: The asn of this IpsecLocalEndpoint.  # noqa: E501
        :type: int
        """

        self._asn = asn

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IpsecLocalEndpoint):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from typing import List

from cohesivenet import VNS3Client, Configuration, data_types
from cohesivenet.macros import api_operations


def get_client(host, username, password, verify=False):
    """Get VNS3 API Client for host

    Arguments:
        host {str}
        username {str}
        password {str}

    Keyword Arguments:
        verify {bool} -- Verify SSL certificate (default: {False})

    Returns:
        [VNS3Client]
    """
    return VNS3Client(
        Configuration(
            host=host, username=username, password=password, verify_ssl=verify
        )
    )


def get_clients(*hosts):
    """Create VNS3Clients for host information

    Arguments:
        host {Dict} -- {
            host: str,
            username: str,
            password: str,
            verify: bool (Optional)
        }

    Returns:
        [List[VNS3Client]]
    """
    return [get_client(**host_data) for host_data in hosts]


def get_clients_common_creds(hosts, common_username, common_password, verify=False):
    """Construct clients for each host

    Arguments:
        hosts {List[str]} -- list of host strings
        common_username {str}
        common_password {str}

    Keyword Arguments:
        verify {bool} -- verify SSL for client

    Returns:
        [List[VNS3Clients]]
    """
    return [
        get_client(host, common_username, common_password, verify) for host in hosts
    ]


def verify_client_connectivity(
    clients: List[VNS3Client],
) -> data_types.BulkOperationResult:
    """Verify the connectivty of provided clients by pinging API

    Arguments:
        clients {List[VNS3Client]}

    Returns:
        data_types.BulkOperationResult
    """

    def _ping_api(_client):
        return _client.sys_admin.get_ping_system()

    return api_operations.__bulk_call_client(clients, _ping_api)



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Topology(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "clients": "list[OverlayIPAddress]",
        "managers": "list[VNS3Controller]",
        "total_clients": "int",
        "ipsec_max_subnets": "int",
        "ipsec_max_endpoints": "int",
        "license_upgrades": "list[str]",
        "overlay_max_clients": "int",
        "overlay_subnet": "str",
    }

    attribute_map = {
        "clients": "clients",
        "managers": "managers",
        "total_clients": "total_clients",
        "ipsec_max_subnets": "ipsec_max_subnets",
        "ipsec_max_endpoints": "ipsec_max_endpoints",
        "license_upgrades": "license_upgrades",
        "overlay_max_clients": "overlay_max_clients",
        "overlay_subnet": "overlay_subnet",
    }

    def __init__(
        self,
        clients=None,
        managers=None,
        total_clients=None,
        ipsec_max_subnets=None,
        ipsec_max_endpoints=None,
        license_upgrades=None,
        overlay_max_clients=None,
        overlay_subnet=None,
    ):  # noqa: E501
        """Topology - a model defined in OpenAPI"""  # noqa: E501

        self._clients = None
        self._managers = None
        self._total_clients = None
        self._ipsec_max_subnets = None
        self._ipsec_max_endpoints = None
        self._license_upgrades = None
        self._overlay_max_clients = None
        self._overlay_subnet = None
        self.discriminator = None

        if clients is not None:
            self.clients = clients
        if managers is not None:
            self.managers = managers
        if total_clients is not None:
            self.total_clients = total_clients
        if ipsec_max_subnets is not None:
            self.ipsec_max_subnets = ipsec_max_subnets
        if ipsec_max_endpoints is not None:
            self.ipsec_max_endpoints = ipsec_max_endpoints
        if license_upgrades is not None:
            self.license_upgrades = license_upgrades
        if overlay_max_clients is not None:
            self.overlay_max_clients = overlay_max_clients
        if overlay_subnet is not None:
            self.overlay_subnet = overlay_subnet

    @property
    def clients(self):
        """Gets the clients of this Topology.  # noqa: E501

        IPs for clientpacks  # noqa: E501

        :return: The clients of this Topology.  # noqa: E501
        :rtype: list[OverlayIPAddress]
        """
        return self._clients

    @clients.setter
    def clients(self, clients):
        """Sets the clients of this Topology.

        IPs for clientpacks  # noqa: E501

        :param clients: The clients of this Topology.  # noqa: E501
        :type: list[OverlayIPAddress]
        """

        self._clients = clients

    @property
    def managers(self):
        """Gets the managers of this Topology.  # noqa: E501


        :return: The managers of this Topology.  # noqa: E501
        :rtype: list[VNS3Controller]
        """
        return self._managers

    @managers.setter
    def managers(self, managers):
        """Sets the managers of this Topology.


        :param managers: The managers of this Topology.  # noqa: E501
        :type: list[VNS3Controller]
        """

        self._managers = managers

    @property
    def total_clients(self):
        """Gets the total_clients of this Topology.  # noqa: E501


        :return: The total_clients of this Topology.  # noqa: E501
        :rtype: int
        """
        return self._total_clients

    @total_clients.setter
    def total_clients(self, total_clients):
        """Sets the total_clients of this Topology.


        :param total_clients: The total_clients of this Topology.  # noqa: E501
        :type: int
        """

        self._total_clients = total_clients

    @property
    def ipsec_max_subnets(self):
        """Gets the ipsec_max_subnets of this Topology.  # noqa: E501


        :return: The ipsec_max_subnets of this Topology.  # noqa: E501
        :rtype: int
        """
        return self._ipsec_max_subnets

    @ipsec_max_subnets.setter
    def ipsec_max_subnets(self, ipsec_max_subnets):
        """Sets the ipsec_max_subnets of this Topology.


        :param ipsec_max_subnets: The ipsec_max_subnets of this Topology.  # noqa: E501
        :type: int
        """

        self._ipsec_max_subnets = ipsec_max_subnets

    @property
    def ipsec_max_endpoints(self):
        """Gets the ipsec_max_endpoints of this Topology.  # noqa: E501


        :return: The ipsec_max_endpoints of this Topology.  # noqa: E501
        :rtype: int
        """
        return self._ipsec_max_endpoints

    @ipsec_max_endpoints.setter
    def ipsec_max_endpoints(self, ipsec_max_endpoints):
        """Sets the ipsec_max_endpoints of this Topology.


        :param ipsec_max_endpoints: The ipsec_max_endpoints of this Topology.  # noqa: E501
        :type: int
        """

        self._ipsec_max_endpoints = ipsec_max_endpoints

    @property
    def license_upgrades(self):
        """Gets the license_upgrades of this Topology.  # noqa: E501


        :return: The license_upgrades of this Topology.  # noqa: E501
        :rtype: list[str]
        """
        return self._license_upgrades

    @license_upgrades.setter
    def license_upgrades(self, license_upgrades):
        """Sets the license_upgrades of this Topology.


        :param license_upgrades: The license_upgrades of this Topology.  # noqa: E501
        :type: list[str]
        """

        self._license_upgrades = license_upgrades

    @property
    def overlay_max_clients(self):
        """Gets the overlay_max_clients of this Topology.  # noqa: E501


        :return: The overlay_max_clients of this Topology.  # noqa: E501
        :rtype: int
        """
        return self._overlay_max_clients

    @overlay_max_clients.setter
    def overlay_max_clients(self, overlay_max_clients):
        """Sets the overlay_max_clients of this Topology.


        :param overlay_max_clients: The overlay_max_clients of this Topology.  # noqa: E501
        :type: int
        """

        self._overlay_max_clients = overlay_max_clients

    @property
    def overlay_subnet(self):
        """Gets the overlay_subnet of this Topology.  # noqa: E501

        CIDR for overlay clients  # noqa: E501

        :return: The overlay_subnet of this Topology.  # noqa: E501
        :rtype: str
        """
        return self._overlay_subnet

    @overlay_subnet.setter
    def overlay_subnet(self, overlay_subnet):
        """Sets the overlay_subnet of this Topology.

        CIDR for overlay clients  # noqa: E501

        :param overlay_subnet: The overlay_subnet of this Topology.  # noqa: E501
        :type: str
        """

        self._overlay_subnet = overlay_subnet

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Topology):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cohesivenet.exceptions import ApiTypeError, ApiValueError


class HighAvailabilityApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            from cohesivenet.vns3_client import VNS3Client

            api_client = VNS3Client()
        self.api_client = api_client

    def get_ha_id(self, **kwargs):  # noqa: E501
        """get_ha_id  # noqa: E501

        Get the unique ID this controller in HA configuration  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ha_id(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: HaUUID
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_ha_id_with_http_info(**kwargs)  # noqa: E501

    def get_ha_id_with_http_info(self, **kwargs):  # noqa: E501
        """get_ha_id  # noqa: E501

        Get the unique ID this controller in HA configuration  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ha_id_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(HaUUID, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ha_id" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/ha/uuid",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="HaUUID",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_ha_status(self, uuid, **kwargs):  # noqa: E501
        """get_ha_status  # noqa: E501

        Get HA status for given ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ha_status(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: HaDetail
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_ha_status_with_http_info(uuid, **kwargs)  # noqa: E501

    def get_ha_status_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """get_ha_status  # noqa: E501

        Get HA status for given ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ha_status_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(HaDetail, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["uuid"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ha_status" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'uuid' is set
        if "uuid" not in local_var_params or local_var_params["uuid"] is None:
            raise ApiValueError(
                "Missing the required parameter `uuid` when calling `get_ha_status`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        if "uuid" in local_var_params:
            query_params.append(("uuid", local_var_params["uuid"]))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/ha/status",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="HaDetail",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_ha_sync_file(self, **kwargs):  # noqa: E501
        """get_ha_sync_file  # noqa: E501

        Download sync file from HA Primary  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ha_sync_file(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_ha_sync_file_with_http_info(**kwargs)  # noqa: E501

    def get_ha_sync_file_with_http_info(self, **kwargs):  # noqa: E501
        """get_ha_sync_file  # noqa: E501

        Download sync file from HA Primary  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ha_sync_file_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(file, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ha_sync_file" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["text/plain", "application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/ha/pull",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="file",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_ha_sync_status(self, uuid, sync_uuid, **kwargs):  # noqa: E501
        """get_ha_sync_status  # noqa: E501

        Get HA sync status for given ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ha_sync_status(uuid, sync_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str uuid: UUID for resource (required)
        :param str sync_uuid: ID for HA sync (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_ha_sync_status_with_http_info(
            uuid, sync_uuid, **kwargs
        )  # noqa: E501

    def get_ha_sync_status_with_http_info(
        self, uuid, sync_uuid, **kwargs
    ):  # noqa: E501
        """get_ha_sync_status  # noqa: E501

        Get HA sync status for given ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ha_sync_status_with_http_info(uuid, sync_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str uuid: UUID for resource (required)
        :param str sync_uuid: ID for HA sync (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["uuid", "sync_uuid"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ha_sync_status" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'uuid' is set
        if "uuid" not in local_var_params or local_var_params["uuid"] is None:
            raise ApiValueError(
                "Missing the required parameter `uuid` when calling `get_ha_sync_status`"
            )  # noqa: E501
        # verify the required parameter 'sync_uuid' is set
        if "sync_uuid" not in local_var_params or local_var_params["sync_uuid"] is None:
            raise ApiValueError(
                "Missing the required parameter `sync_uuid` when calling `get_ha_sync_status`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if "uuid" in local_var_params:
            query_params.append(("uuid", local_var_params["uuid"]))  # noqa: E501
        if "sync_uuid" in local_var_params:
            query_params.append(
                ("sync_uuid", local_var_params["sync_uuid"])
            )  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/ha/sync",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_init_ha(self, init_ha_request, **kwargs):  # noqa: E501
        """post_init_ha  # noqa: E501

        Initialise HA  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_init_ha(init_ha_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param InitHaRequest init_ha_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_init_ha_with_http_info(init_ha_request, **kwargs)  # noqa: E501

    def post_init_ha_with_http_info(self, init_ha_request, **kwargs):  # noqa: E501
        """post_init_ha  # noqa: E501

        Initialise HA  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_init_ha_with_http_info(init_ha_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param InitHaRequest init_ha_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["init_ha_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_init_ha" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'init_ha_request' is set
        if (
            "init_ha_request" not in local_var_params
            or local_var_params["init_ha_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `init_ha_request` when calling `post_init_ha`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "init_ha_request" in local_var_params:
            body_params = local_var_params["init_ha_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/ha/init",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_sync_ha(self, body, **kwargs):  # noqa: E501
        """post_sync_ha  # noqa: E501

        Initiate a sync creation on HA Primary  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_ha(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param object body: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: HaSyncStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_sync_ha_with_http_info(body, **kwargs)  # noqa: E501

    def post_sync_ha_with_http_info(self, body, **kwargs):  # noqa: E501
        """post_sync_ha  # noqa: E501

        Initiate a sync creation on HA Primary  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_ha_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param object body: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(HaSyncStatusResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sync_ha" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in local_var_params or local_var_params["body"] is None:
            raise ApiValueError(
                "Missing the required parameter `body` when calling `post_sync_ha`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in local_var_params:
            body_params = local_var_params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/ha/sync",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="HaSyncStatusResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def put_ha_activate(self, activate_ha_request, **kwargs):  # noqa: E501
        """put_ha_activate  # noqa: E501

        Activate the HA switchover  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_ha_activate(activate_ha_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ActivateHaRequest activate_ha_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.put_ha_activate_with_http_info(
            activate_ha_request, **kwargs
        )  # noqa: E501

    def put_ha_activate_with_http_info(
        self, activate_ha_request, **kwargs
    ):  # noqa: E501
        """put_ha_activate  # noqa: E501

        Activate the HA switchover  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_ha_activate_with_http_info(activate_ha_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ActivateHaRequest activate_ha_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["activate_ha_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_ha_activate" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'activate_ha_request' is set
        if (
            "activate_ha_request" not in local_var_params
            or local_var_params["activate_ha_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `activate_ha_request` when calling `put_ha_activate`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "activate_ha_request" in local_var_params:
            body_params = local_var_params["activate_ha_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/ha/activate",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def put_ha_push_file(self, body, **kwargs):  # noqa: E501
        """put_ha_push_file  # noqa: E501

        Upload a sync file to HA Backup  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_ha_push_file(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param file body: Sync file (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.put_ha_push_file_with_http_info(body, **kwargs)  # noqa: E501

    def put_ha_push_file_with_http_info(self, body, **kwargs):  # noqa: E501
        """put_ha_push_file  # noqa: E501

        Upload a sync file to HA Backup  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_ha_push_file_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param file body: Sync file (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_ha_push_file" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in local_var_params or local_var_params["body"] is None:
            raise ApiValueError(
                "Missing the required parameter `body` when calling `put_ha_push_file`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in local_var_params:
            body_params = local_var_params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["text/plain"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/ha/push",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

import cohesivenet
from cohesivenet.api.vns3.licensing_api import LicensingApi  # noqa: E501
from cohesivenet.rest import ApiException


class TestLicensingApi(object):
    """LicensingApi unit test stubs"""

    @pytest.mark.licensed
    def test_get_license(self):
        """Test case for get_license

        """
        pass

    @pytest.mark.licensed
    def test_put_license_upgrade(self):
        """Test case for put_license_upgrade

        """
        pass

    def test_put_set_license_parameters(self):
        """Test case for put_set_license_parameters

        """
        pass

    def test_upload_license(self):
        """Test case for upload_license

        """
        pass



import logging
import re
import six
from collections import OrderedDict
from typing import Dict, List

# Log handler is configured if provided in ENV. Configured end of file (EOF)

DEBUG = "debug"
INFO = "info"
ERROR = "error"


def logfmt(props):
    def fmt(key, val):
        # Handle case where val is a bytes or bytesarray
        if six.PY3 and hasattr(val, "decode"):
            val = val.decode("utf-8")
        # Check if val is already a string to avoid re-encoding into
        # ascii. Since the code is sent through 2to3, we can't just
        # use unicode(val, encoding='utf8') since it will be
        # translated incorrectly.
        if not isinstance(val, six.string_types):
            val = six.text_type(val)
        if re.search(r"\s", val):
            val = repr(val)
        # key should already be a string
        if re.search(r"\s", key):
            key = repr(key)
        return u"{key}={val}".format(key=key, val=val)

    return u" ".join([fmt(key, val) for key, val in props.items()])


def _format_msg(message, **params):
    props = OrderedDict(message=message)
    props.update(params)
    return logfmt(props)


def scrub_sensitive(data: Dict, secrets: List[str]):
    return {k: v if k not in secrets else "****" for k, v in data.items()}


def silence_urllib3(warnings_only=False):
    import urllib3

    urllib3.disable_warnings()
    if warnings_only:
        return

    logging.getLogger("urllib3").propagate = False


class _Logger(object):
    DEFAULT_LOG_FORMAT = "[%(asctime)s] [%(name)s] [%(levelname)s] [%(message)s]"

    def __init__(self):
        self._logger = logging.getLogger("cohesivenet")
        self.format = self.DEFAULT_LOG_FORMAT

    def debug(self, message, **params):
        self._logger.debug(_format_msg(message, **params))

    def info(self, message, **params):
        self._logger.info(_format_msg(message, **params))

    def error(self, message, **params):
        self._logger.error(_format_msg(message, **params))

    def set_null(self):
        self._logger.addHandler(logging.NullHandler())

    def set_stream_handler(self, log_level):
        if not log_level:
            return

        valid_level = None
        if log_level == "debug":
            valid_level = logging.DEBUG
        elif log_level == "info":
            valid_level = logging.INFO
        elif log_level == "error":
            valid_level = logging.ERROR

        if valid_level:
            self._logger.handlers = []
            console = logging.StreamHandler()
            console.setFormatter(logging.Formatter(self.format))
            console.setLevel(valid_level)
            self._logger.addHandler(console)
            self._logger.setLevel(valid_level)
            return True
        else:
            print(
                "!!! LOG SETUP ERROR - Level must be one of debug,info or error. No logging configured."
            )
            return False

    def silence_urllib3(self, warnings_only=False):
        silence_urllib3(warnings_only=warnings_only)


Logger = _Logger()



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class RunningContainersDetailState(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "running": "bool",
        "pid": "int",
        "exit_code": "int",
        "started_at": "str",
        "finished_at": "str",
        "ghost": "bool",
    }

    attribute_map = {
        "running": "Running",
        "pid": "Pid",
        "exit_code": "ExitCode",
        "started_at": "StartedAt",
        "finished_at": "FinishedAt",
        "ghost": "Ghost",
    }

    def __init__(
        self,
        running=None,
        pid=None,
        exit_code=None,
        started_at=None,
        finished_at=None,
        ghost=None,
    ):  # noqa: E501
        """RunningContainersDetailState - a model defined in OpenAPI"""  # noqa: E501

        self._running = None
        self._pid = None
        self._exit_code = None
        self._started_at = None
        self._finished_at = None
        self._ghost = None
        self.discriminator = None

        if running is not None:
            self.running = running
        if pid is not None:
            self.pid = pid
        if exit_code is not None:
            self.exit_code = exit_code
        if started_at is not None:
            self.started_at = started_at
        if finished_at is not None:
            self.finished_at = finished_at
        if ghost is not None:
            self.ghost = ghost

    @property
    def running(self):
        """Gets the running of this RunningContainersDetailState.  # noqa: E501


        :return: The running of this RunningContainersDetailState.  # noqa: E501
        :rtype: bool
        """
        return self._running

    @running.setter
    def running(self, running):
        """Sets the running of this RunningContainersDetailState.


        :param running: The running of this RunningContainersDetailState.  # noqa: E501
        :type: bool
        """

        self._running = running

    @property
    def pid(self):
        """Gets the pid of this RunningContainersDetailState.  # noqa: E501


        :return: The pid of this RunningContainersDetailState.  # noqa: E501
        :rtype: int
        """
        return self._pid

    @pid.setter
    def pid(self, pid):
        """Sets the pid of this RunningContainersDetailState.


        :param pid: The pid of this RunningContainersDetailState.  # noqa: E501
        :type: int
        """

        self._pid = pid

    @property
    def exit_code(self):
        """Gets the exit_code of this RunningContainersDetailState.  # noqa: E501


        :return: The exit_code of this RunningContainersDetailState.  # noqa: E501
        :rtype: int
        """
        return self._exit_code

    @exit_code.setter
    def exit_code(self, exit_code):
        """Sets the exit_code of this RunningContainersDetailState.


        :param exit_code: The exit_code of this RunningContainersDetailState.  # noqa: E501
        :type: int
        """

        self._exit_code = exit_code

    @property
    def started_at(self):
        """Gets the started_at of this RunningContainersDetailState.  # noqa: E501


        :return: The started_at of this RunningContainersDetailState.  # noqa: E501
        :rtype: str
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        """Sets the started_at of this RunningContainersDetailState.


        :param started_at: The started_at of this RunningContainersDetailState.  # noqa: E501
        :type: str
        """

        self._started_at = started_at

    @property
    def finished_at(self):
        """Gets the finished_at of this RunningContainersDetailState.  # noqa: E501


        :return: The finished_at of this RunningContainersDetailState.  # noqa: E501
        :rtype: str
        """
        return self._finished_at

    @finished_at.setter
    def finished_at(self, finished_at):
        """Sets the finished_at of this RunningContainersDetailState.


        :param finished_at: The finished_at of this RunningContainersDetailState.  # noqa: E501
        :type: str
        """

        self._finished_at = finished_at

    @property
    def ghost(self):
        """Gets the ghost of this RunningContainersDetailState.  # noqa: E501


        :return: The ghost of this RunningContainersDetailState.  # noqa: E501
        :rtype: bool
        """
        return self._ghost

    @ghost.setter
    def ghost(self, ghost):
        """Sets the ghost of this RunningContainersDetailState.


        :param ghost: The ghost of this RunningContainersDetailState.  # noqa: E501
        :type: bool
        """

        self._ghost = ghost

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RunningContainersDetailState):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
